==> ucscsdk-0.9.0.2.tar.gz: ucscsdk-0.9.0.2/ucscsdk/mometa/bios/BiosVfOutOfBandManagement.py <==
"""This module contains the general information for BiosVfOutOfBandManagement ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class BiosVfOutOfBandManagementConsts():
    SUPPORTED_BY_DEFAULT_NO = "no"
    SUPPORTED_BY_DEFAULT_YES = "yes"
    VP_COM_SPCR_ENABLE_DISABLED = "disabled"
    VP_COM_SPCR_ENABLE_ENABLED = "enabled"
    VP_COM_SPCR_ENABLE_PLATFORM_DEFAULT = "platform-default"
    VP_COM_SPCR_ENABLE_PLATFORM_RECOMMENDED = "platform-recommended"


class BiosVfOutOfBandManagement(ManagedObject):
    """This is BiosVfOutOfBandManagement class."""

    consts = BiosVfOutOfBandManagementConsts()
    naming_props = set([])

    mo_meta = MoMeta("BiosVfOutOfBandManagement", "biosVfOutOfBandManagement", "Out-of-Band-Management", VersionMeta.Version201b, "InputOutput", 0x1f, [], ["read-only"], [u'biosVProfile'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "supported_by_default": MoPropertyMeta("supported_by_default", "supportedByDefault", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []), 
        "vp_com_spcr_enable": MoPropertyMeta("vp_com_spcr_enable", "vpComSpcrEnable", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "status": "status", 
        "supportedByDefault": "supported_by_default", 
        "vpComSpcrEnable": "vp_com_spcr_enable", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.status = None
        self.supported_by_default = None
        self.vp_com_spcr_enable = None

        ManagedObject.__init__(self, "BiosVfOutOfBandManagement", parent_mo_or_dn, **kwargs)

==> ucscsdk-0.9.0.10.tar.gz: ucscsdk-0.9.0.10/ucscsdk/mometa/bios/BiosVfOutOfBandManagement.py <==
"""This module contains the general information for BiosVfOutOfBandManagement ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class BiosVfOutOfBandManagementConsts():
    SUPPORTED_BY_DEFAULT_NO = "no"
    SUPPORTED_BY_DEFAULT_YES = "yes"
    VP_COM_SPCR_ENABLE_DISABLED = "disabled"
    VP_COM_SPCR_ENABLE_ENABLED = "enabled"
    VP_COM_SPCR_ENABLE_PLATFORM_DEFAULT = "platform-default"
    VP_COM_SPCR_ENABLE_PLATFORM_RECOMMENDED = "platform-recommended"


class BiosVfOutOfBandManagement(ManagedObject):
    """This is BiosVfOutOfBandManagement class."""

    consts = BiosVfOutOfBandManagementConsts()
    naming_props = set([])

    mo_meta = MoMeta("BiosVfOutOfBandManagement", "biosVfOutOfBandManagement", "Out-of-Band-Management", VersionMeta.Version201b, "InputOutput", 0x1f, [], ["read-only"], ['biosVProfile'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "supported_by_default": MoPropertyMeta("supported_by_default", "supportedByDefault", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []), 
        "vp_com_spcr_enable": MoPropertyMeta("vp_com_spcr_enable", "vpComSpcrEnable", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "status": "status", 
        "supportedByDefault": "supported_by_default", 
        "vpComSpcrEnable": "vp_com_spcr_enable", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.status = None
        self.supported_by_default = None
        self.vp_com_spcr_enable = None

        ManagedObject.__init__(self, "BiosVfOutOfBandManagement", parent_mo_or_dn, **kwargs)
